PKey

Struct PKey 

pub struct PKey<T> { /* private fields */ }
This is a wrapper around an asymmetric key pair. Since the PKey is either a public or private key so we have to differentiate that as well.

Implementations

Source

impl PKey<RsaPrivateKey>

pub fn new(bit_length: u32) -> Result<PrivateKey, Error>

Generate a new private key with the given length in bits.

pub fn read_pem_file(path: &Path) -> Result<PrivateKey, PKeyError>

Read a private key from the given path.

pub fn from_pem(bytes: &[u8]) -> Result<PrivateKey, PKeyError>

Create a private key from a pem file loaded into a byte array.

pub fn to_der(&self) -> Result<SecretDocument>

Serialize the private key to a der file.

pub fn public_key_to_info(&self) -> Result<SubjectPublicKeyInfoOwned>

Get the public key info for this private key.

pub fn to_public_key(&self) -> PublicKey

Create a public key based on this private key.

pub fn sign_sha1( &self, data: &[u8], signature: &mut [u8], ) -> Result<usize, Error>

Signs the data using RSA-SHA1

pub fn sign_sha256( &self, data: &[u8], signature: &mut [u8], ) -> Result<usize, Error>

Signs the data using RSA-SHA256

pub fn sign_sha256_pss( &self, data: &[u8], signature: &mut [u8], ) -> Result<usize, Error>

Signs the data using RSA-SHA256-PSS

Source

impl PKey<RsaPublicKey>

pub fn verify_sha1(&self, data: &[u8], signature: &[u8]) -> Result<bool, Error>

Verifies the data using RSA-SHA1

pub fn verify_sha256( &self, data: &[u8], signature: &[u8], ) -> Result<bool, Error>

Verifies the data using RSA-SHA256

pub fn verify_sha256_pss( &self, data: &[u8], signature: &[u8], ) -> Result<bool, Error>

Verifies the data using RSA-SHA256-PSS